var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};

// src/index.ts
import { resolve } from "path";
import { ESLint } from "eslint";
import { createFilter } from "@rollup/pluginutils";

// package.json
var name = "vite-plugin-eslint";

// src/utils.ts
function parseRequest(id) {
  const [filename] = id.split("?", 2);
  return filename;
}

// src/index.ts
function eslintPlugin(options = {}) {
  let eslint;
  let filter;
  let formatter;
  let userOptions;
  return {
    name,
    async configResolved(config) {
      userOptions = Object.assign({
        include: /\.(jsx?|tsx?|vue|svelte)$/,
        exclude: /node_modules/,
        cacheLocation: resolve(config.cacheDir, ".eslintcache"),
        formatter: "stylish",
        throwOnWarning: true,
        throwOnError: true
      }, options);
      const _a = userOptions, {
        include,
        exclude,
        formatter: userFormatter,
        throwOnError,
        throwOnWarning
      } = _a, eslintOptions = __objRest(_a, [
        "include",
        "exclude",
        "formatter",
        "throwOnError",
        "throwOnWarning"
      ]);
      filter = createFilter(include, exclude);
      eslint = new ESLint(eslintOptions);
      switch (typeof userFormatter) {
        case "string":
          formatter = (await eslint.loadFormatter(userFormatter)).format;
          break;
        case "function":
          formatter = userFormatter;
        default:
          break;
      }
    },
    async transform(_, id) {
      const filePath = parseRequest(id);
      if (!filter(filePath) || await eslint.isPathIgnored(filePath)) {
        return null;
      }
      const report = await eslint.lintFiles(filePath);
      const hasWarnings = userOptions.throwOnWarning && report.some((item) => item.warningCount > 0);
      const hasErrors = userOptions.throwOnError && report.some((item) => item.errorCount > 0);
      const result = formatter(report);
      if (userOptions.fix && report) {
        ESLint.outputFixes(report);
      }
      if (hasWarnings) {
        this.warn(typeof result === "string" ? result : await result);
      }
      if (hasErrors) {
        this.error(typeof result === "string" ? result : await result);
      }
      return null;
    }
  };
}
export {
  eslintPlugin as default
};
